@@ -1,6 +1,6 @@
 from django.utils.version import get_version
 
-VERSION = (4, 0, 2, 'final', 0)
+VERSION = (4, 0, 5, "final", 0)
 
 __version__ = get_version(VERSION)
 
@@ -19,6 +19,6 @@ def setup(set_prefix=True):
     configure_logging(settings.LOGGING_CONFIG, settings.LOGGING)
     if set_prefix:
         set_script_prefix(
-            '/' if settings.FORCE_SCRIPT_NAME is None else settings.FORCE_SCRIPT_NAME
+            "/" if settings.FORCE_SCRIPT_NAME is None else settings.FORCE_SCRIPT_NAME
         )
     apps.populate(settings.INSTALLED_APPS)
