@@ -1,42 +1,50 @@
-from __future__ import unicode_literals
-
 from django.db import models
 from django.test import TestCase
-from django.utils import six
 
 from .models import (
-    Book, Car, CustomManager, CustomQuerySet, DeconstructibleCustomManager,
-    FunPerson, OneToOneRestrictedModel, Person, PersonFromAbstract,
-    PersonManager, PublishedBookManager, RelatedModel, RestrictedModel,
+    Book,
+    Car,
+    CustomManager,
+    CustomQuerySet,
+    DeconstructibleCustomManager,
+    FastCarAsBase,
+    FastCarAsDefault,
+    FunPerson,
+    OneToOneRestrictedModel,
+    Person,
+    PersonFromAbstract,
+    PersonManager,
+    PublishedBookManager,
+    RelatedModel,
+    RestrictedModel,
 )
 
 
 class CustomManagerTests(TestCase):
     custom_manager_names = [
-        'custom_queryset_default_manager',
-        'custom_queryset_custom_manager',
+        "custom_queryset_default_manager",
+        "custom_queryset_custom_manager",
     ]
 
     @classmethod
     def setUpTestData(cls):
         cls.b1 = Book.published_objects.create(
-            title="How to program", author="Rodney Dangerfield", is_published=True)
+            title="How to program", author="Rodney Dangerfield", is_published=True
+        )
         cls.b2 = Book.published_objects.create(
-            title="How to be smart", author="Albert Einstein", is_published=False)
+            title="How to be smart", author="Albert Einstein", is_published=False
+        )
 
         cls.p1 = Person.objects.create(first_name="Bugs", last_name="Bunny", fun=True)
-        cls.droopy = Person.objects.create(first_name="Droopy", last_name="Dog", fun=False)
+        cls.droopy = Person.objects.create(
+            first_name="Droopy", last_name="Dog", fun=False
+        )
 
     def test_custom_manager_basic(self):
         """
         Test a custom Manager method.
         """
-        self.assertQuerysetEqual(
-            Person.objects.get_fun_people(), [
-                "Bugs Bunny"
-            ],
-            six.text_type
-        )
+        self.assertQuerysetEqual(Person.objects.get_fun_people(), ["Bugs Bunny"], str)
 
     def test_queryset_copied_to_default(self):
         """
@@ -44,47 +52,54 @@ class CustomManagerTests(TestCase):
         default Manager.
         """
         for manager_name in self.custom_manager_names:
-            manager = getattr(Person, manager_name)
+            with self.subTest(manager_name=manager_name):
+                manager = getattr(Person, manager_name)
 
-            # Public methods are copied
-            manager.public_method()
-            # Private methods are not copied
-            with self.assertRaises(AttributeError):
-                manager._private_method()
+                # Public methods are copied
+                manager.public_method()
+                # Private methods are not copied
+                with self.assertRaises(AttributeError):
+                    manager._private_method()
 
     def test_manager_honors_queryset_only(self):
         for manager_name in self.custom_manager_names:
-            manager = getattr(Person, manager_name)
-            # Methods with queryset_only=False are copied even if they are private.
-            manager._optin_private_method()
-            # Methods with queryset_only=True aren't copied even if they are public.
-            with self.assertRaises(AttributeError):
-                manager.optout_public_method()
+            with self.subTest(manager_name=manager_name):
+                manager = getattr(Person, manager_name)
+                # Methods with queryset_only=False are copied even if they are private.
+                manager._optin_private_method()
+                # Methods with queryset_only=True aren't copied even if they are public.
+                msg = (
+                    "%r object has no attribute 'optout_public_method'"
+                    % manager.__class__.__name__
+                )
+                with self.assertRaisesMessage(AttributeError, msg):
+                    manager.optout_public_method()
 
     def test_manager_use_queryset_methods(self):
         """
         Custom manager will use the queryset methods
         """
         for manager_name in self.custom_manager_names:
-            manager = getattr(Person, manager_name)
-            queryset = manager.filter()
-            self.assertQuerysetEqual(queryset, ["Bugs Bunny"], six.text_type)
-            self.assertEqual(queryset._filter_CustomQuerySet, True)
+            with self.subTest(manager_name=manager_name):
+                manager = getattr(Person, manager_name)
+                queryset = manager.filter()
+                self.assertQuerysetEqual(queryset, ["Bugs Bunny"], str)
+                self.assertIs(queryset._filter_CustomQuerySet, True)
 
-            # Test that specialized querysets inherit from our custom queryset.
-            queryset = manager.values_list('first_name', flat=True).filter()
-            self.assertEqual(list(queryset), [six.text_type("Bugs")])
-            self.assertEqual(queryset._filter_CustomQuerySet, True)
+                # Specialized querysets inherit from our custom queryset.
+                queryset = manager.values_list("first_name", flat=True).filter()
+                self.assertEqual(list(queryset), ["Bugs"])
+                self.assertIs(queryset._filter_CustomQuerySet, True)
 
-            self.assertIsInstance(queryset.values(), CustomQuerySet)
-            self.assertIsInstance(queryset.values().values(), CustomQuerySet)
-            self.assertIsInstance(queryset.values_list().values(), CustomQuerySet)
+                self.assertIsInstance(queryset.values(), CustomQuerySet)
+                self.assertIsInstance(queryset.values().values(), CustomQuerySet)
+                self.assertIsInstance(queryset.values_list().values(), CustomQuerySet)
 
     def test_init_args(self):
         """
         The custom manager __init__() argument has been set.
         """
-        self.assertEqual(Person.custom_queryset_custom_manager.init_arg, 'hello')
+        self.assertEqual(Person.custom_queryset_custom_manager.init_arg, "hello")
 
     def test_manager_attributes(self):
         """
@@ -92,7 +107,8 @@ class CustomManagerTests(TestCase):
         querysets.
         """
         Person.custom_queryset_custom_manager.manager_only()
-        with self.assertRaises(AttributeError):
+        msg = "'CustomQuerySet' object has no attribute 'manager_only'"
+        with self.assertRaisesMessage(AttributeError, msg):
             Person.custom_queryset_custom_manager.all().manager_only()
 
     def test_queryset_and_manager(self):
@@ -100,8 +116,8 @@ class CustomManagerTests(TestCase):
         Queryset method doesn't override the custom manager method.
         """
         queryset = Person.custom_queryset_custom_manager.filter()
-        self.assertQuerysetEqual(queryset, ["Bugs Bunny"], six.text_type)
-        self.assertEqual(queryset._filter_CustomManager, True)
+        self.assertQuerysetEqual(queryset, ["Bugs Bunny"], str)
+        self.assertIs(queryset._filter_CustomManager, True)
 
     def test_related_manager(self):
         """
@@ -115,27 +131,39 @@ class CustomManagerTests(TestCase):
         The default manager, "objects", doesn't exist, because a custom one
         was provided.
         """
-        self.assertRaises(AttributeError, lambda: Book.objects)
+        msg = "type object 'Book' has no attribute 'objects'"
+        with self.assertRaisesMessage(AttributeError, msg):
+            Book.objects
 
     def test_filtering(self):
         """
         Custom managers respond to usual filtering methods
         """
         self.assertQuerysetEqual(
-            Book.published_objects.all(), [
+            Book.published_objects.all(),
+            [
                 "How to program",
             ],
-            lambda b: b.title
+            lambda b: b.title,
         )
 
     def test_fk_related_manager(self):
-        Person.objects.create(first_name="Bugs", last_name="Bunny", fun=True, favorite_book=self.b1)
-        Person.objects.create(first_name="Droopy", last_name="Dog", fun=False, favorite_book=self.b1)
-        FunPerson.objects.create(first_name="Bugs", last_name="Bunny", fun=True, favorite_book=self.b1)
-        FunPerson.objects.create(first_name="Droopy", last_name="Dog", fun=False, favorite_book=self.b1)
+        Person.objects.create(
+            first_name="Bugs", last_name="Bunny", fun=True, favorite_book=self.b1
+        )
+        Person.objects.create(
+            first_name="Droopy", last_name="Dog", fun=False, favorite_book=self.b1
+        )
+        FunPerson.objects.create(
+            first_name="Bugs", last_name="Bunny", fun=True, favorite_book=self.b1
+        )
+        FunPerson.objects.create(
+            first_name="Droopy", last_name="Dog", fun=False, favorite_book=self.b1
+        )
 
         self.assertQuerysetEqual(
-            self.b1.favorite_books.order_by('first_name').all(), [
+            self.b1.favorite_books.order_by("first_name").all(),
+            [
                 "Bugs",
                 "Droopy",
             ],
@@ -143,21 +171,24 @@ class CustomManagerTests(TestCase):
             ordered=False,
         )
         self.assertQuerysetEqual(
-            self.b1.fun_people_favorite_books.all(), [
+            self.b1.fun_people_favorite_books.all(),
+            [
                 "Bugs",
             ],
             lambda c: c.first_name,
             ordered=False,
         )
         self.assertQuerysetEqual(
-            self.b1.favorite_books(manager='boring_people').all(), [
+            self.b1.favorite_books(manager="boring_people").all(),
+            [
                 "Droopy",
             ],
             lambda c: c.first_name,
             ordered=False,
         )
         self.assertQuerysetEqual(
-            self.b1.favorite_books(manager='fun_people').all(), [
+            self.b1.favorite_books(manager="fun_people").all(),
+            [
                 "Bugs",
             ],
             lambda c: c.first_name,
@@ -165,13 +196,22 @@ class CustomManagerTests(TestCase):
         )
 
     def test_gfk_related_manager(self):
-        Person.objects.create(first_name="Bugs", last_name="Bunny", fun=True, favorite_thing=self.b1)
-        Person.objects.create(first_name="Droopy", last_name="Dog", fun=False, favorite_thing=self.b1)
-        FunPerson.objects.create(first_name="Bugs", last_name="Bunny", fun=True, favorite_thing=self.b1)
-        FunPerson.objects.create(first_name="Droopy", last_name="Dog", fun=False, favorite_thing=self.b1)
+        Person.objects.create(
+            first_name="Bugs", last_name="Bunny", fun=True, favorite_thing=self.b1
+        )
+        Person.objects.create(
+            first_name="Droopy", last_name="Dog", fun=False, favorite_thing=self.b1
+        )
+        FunPerson.objects.create(
+            first_name="Bugs", last_name="Bunny", fun=True, favorite_thing=self.b1
+        )
+        FunPerson.objects.create(
+            first_name="Droopy", last_name="Dog", fun=False, favorite_thing=self.b1
+        )
 
         self.assertQuerysetEqual(
-            self.b1.favorite_things.all(), [
+            self.b1.favorite_things.all(),
+            [
                 "Bugs",
                 "Droopy",
             ],
@@ -179,21 +219,24 @@ class CustomManagerTests(TestCase):
             ordered=False,
         )
         self.assertQuerysetEqual(
-            self.b1.fun_people_favorite_things.all(), [
+            self.b1.fun_people_favorite_things.all(),
+            [
                 "Bugs",
             ],
             lambda c: c.first_name,
             ordered=False,
         )
         self.assertQuerysetEqual(
-            self.b1.favorite_things(manager='boring_people').all(), [
+            self.b1.favorite_things(manager="boring_people").all(),
+            [
                 "Droopy",
             ],
             lambda c: c.first_name,
             ordered=False,
         )
         self.assertQuerysetEqual(
-            self.b1.favorite_things(manager='fun_people').all(), [
+            self.b1.favorite_things(manager="fun_people").all(),
+            [
                 "Bugs",
             ],
             lambda c: c.first_name,
@@ -207,11 +250,14 @@ class CustomManagerTests(TestCase):
         self.b1.authors.add(droopy)
         bugs = FunPerson.objects.create(first_name="Bugs", last_name="Bunny", fun=True)
         self.b1.fun_authors.add(bugs)
-        droopy = FunPerson.objects.create(first_name="Droopy", last_name="Dog", fun=False)
+        droopy = FunPerson.objects.create(
+            first_name="Droopy", last_name="Dog", fun=False
+        )
         self.b1.fun_authors.add(droopy)
 
         self.assertQuerysetEqual(
-            self.b1.authors.order_by('first_name').all(), [
+            self.b1.authors.order_by("first_name").all(),
+            [
                 "Bugs",
                 "Droopy",
             ],
@@ -219,21 +265,24 @@ class CustomManagerTests(TestCase):
             ordered=False,
         )
         self.assertQuerysetEqual(
-            self.b1.fun_authors.order_by('first_name').all(), [
+            self.b1.fun_authors.order_by("first_name").all(),
+            [
                 "Bugs",
             ],
             lambda c: c.first_name,
             ordered=False,
         )
         self.assertQuerysetEqual(
-            self.b1.authors(manager='boring_people').all(), [
+            self.b1.authors(manager="boring_people").all(),
+            [
                 "Droopy",
             ],
             lambda c: c.first_name,
             ordered=False,
         )
         self.assertQuerysetEqual(
-            self.b1.authors(manager='fun_people').all(), [
+            self.b1.authors(manager="fun_people").all(),
+            [
                 "Bugs",
             ],
             lambda c: c.first_name,
@@ -241,12 +290,17 @@ class CustomManagerTests(TestCase):
         )
 
     def test_removal_through_default_fk_related_manager(self, bulk=True):
-        bugs = FunPerson.objects.create(first_name="Bugs", last_name="Bunny", fun=True, favorite_book=self.b1)
-        droopy = FunPerson.objects.create(first_name="Droopy", last_name="Dog", fun=False, favorite_book=self.b1)
+        bugs = FunPerson.objects.create(
+            first_name="Bugs", last_name="Bunny", fun=True, favorite_book=self.b1
+        )
+        droopy = FunPerson.objects.create(
+            first_name="Droopy", last_name="Dog", fun=False, favorite_book=self.b1
+        )
 
         self.b1.fun_people_favorite_books.remove(droopy, bulk=bulk)
         self.assertQuerysetEqual(
-            FunPerson._base_manager.filter(favorite_book=self.b1), [
+            FunPerson._base_manager.filter(favorite_book=self.b1),
+            [
                 "Bugs",
                 "Droopy",
             ],
@@ -256,7 +310,8 @@ class CustomManagerTests(TestCase):
 
         self.b1.fun_people_favorite_books.remove(bugs, bulk=bulk)
         self.assertQuerysetEqual(
-            FunPerson._base_manager.filter(favorite_book=self.b1), [
+            FunPerson._base_manager.filter(favorite_book=self.b1),
+            [
                 "Droopy",
             ],
             lambda c: c.first_name,
@@ -267,7 +322,8 @@ class CustomManagerTests(TestCase):
 
         self.b1.fun_people_favorite_books.clear(bulk=bulk)
         self.assertQuerysetEqual(
-            FunPerson._base_manager.filter(favorite_book=self.b1), [
+            FunPerson._base_manager.filter(favorite_book=self.b1),
+            [
                 "Droopy",
             ],
             lambda c: c.first_name,
@@ -278,41 +334,47 @@ class CustomManagerTests(TestCase):
         self.test_removal_through_default_fk_related_manager(bulk=False)
 
     def test_removal_through_specified_fk_related_manager(self, bulk=True):
-        Person.objects.create(first_name="Bugs", last_name="Bunny", fun=True, favorite_book=self.b1)
-        droopy = Person.objects.create(first_name="Droopy", last_name="Dog", fun=False, favorite_book=self.b1)
+        Person.objects.create(
+            first_name="Bugs", last_name="Bunny", fun=True, favorite_book=self.b1
+        )
+        droopy = Person.objects.create(
+            first_name="Droopy", last_name="Dog", fun=False, favorite_book=self.b1
+        )
 
-        # Check that the fun manager DOESN'T remove boring people.
-        self.b1.favorite_books(manager='fun_people').remove(droopy, bulk=bulk)
+        # The fun manager DOESN'T remove boring people.
+        self.b1.favorite_books(manager="fun_people").remove(droopy, bulk=bulk)
         self.assertQuerysetEqual(
-            self.b1.favorite_books(manager='boring_people').all(), [
+            self.b1.favorite_books(manager="boring_people").all(),
+            [
                 "Droopy",
             ],
             lambda c: c.first_name,
             ordered=False,
         )
-        # Check that the boring manager DOES remove boring people.
-        self.b1.favorite_books(manager='boring_people').remove(droopy, bulk=bulk)
+        # The boring manager DOES remove boring people.
+        self.b1.favorite_books(manager="boring_people").remove(droopy, bulk=bulk)
         self.assertQuerysetEqual(
-            self.b1.favorite_books(manager='boring_people').all(), [
-            ],
+            self.b1.favorite_books(manager="boring_people").all(),
+            [],
             lambda c: c.first_name,
             ordered=False,
         )
         droopy.favorite_book = self.b1
         droopy.save()
 
-        # Check that the fun manager ONLY clears fun people.
-        self.b1.favorite_books(manager='fun_people').clear(bulk=bulk)
+        # The fun manager ONLY clears fun people.
+        self.b1.favorite_books(manager="fun_people").clear(bulk=bulk)
         self.assertQuerysetEqual(
-            self.b1.favorite_books(manager='boring_people').all(), [
+            self.b1.favorite_books(manager="boring_people").all(),
+            [
                 "Droopy",
             ],
             lambda c: c.first_name,
             ordered=False,
         )
         self.assertQuerysetEqual(
-            self.b1.favorite_books(manager='fun_people').all(), [
-            ],
+            self.b1.favorite_books(manager="fun_people").all(),
+            [],
             lambda c: c.first_name,
             ordered=False,
         )
@@ -321,12 +383,19 @@ class CustomManagerTests(TestCase):
         self.test_removal_through_specified_fk_related_manager(bulk=False)
 
     def test_removal_through_default_gfk_related_manager(self, bulk=True):
-        bugs = FunPerson.objects.create(first_name="Bugs", last_name="Bunny", fun=True, favorite_thing=self.b1)
-        droopy = FunPerson.objects.create(first_name="Droopy", last_name="Dog", fun=False, favorite_thing=self.b1)
+        bugs = FunPerson.objects.create(
+            first_name="Bugs", last_name="Bunny", fun=True, favorite_thing=self.b1
+        )
+        droopy = FunPerson.objects.create(
+            first_name="Droopy", last_name="Dog", fun=False, favorite_thing=self.b1
+        )
 
         self.b1.fun_people_favorite_things.remove(droopy, bulk=bulk)
         self.assertQuerysetEqual(
-            FunPerson._base_manager.order_by('first_name').filter(favorite_thing_id=self.b1.pk), [
+            FunPerson._base_manager.order_by("first_name").filter(
+                favorite_thing_id=self.b1.pk
+            ),
+            [
                 "Bugs",
                 "Droopy",
             ],
@@ -336,7 +405,10 @@ class CustomManagerTests(TestCase):
 
         self.b1.fun_people_favorite_things.remove(bugs, bulk=bulk)
         self.assertQuerysetEqual(
-            FunPerson._base_manager.order_by('first_name').filter(favorite_thing_id=self.b1.pk), [
+            FunPerson._base_manager.order_by("first_name").filter(
+                favorite_thing_id=self.b1.pk
+            ),
+            [
                 "Droopy",
             ],
             lambda c: c.first_name,
@@ -347,7 +419,10 @@ class CustomManagerTests(TestCase):
 
         self.b1.fun_people_favorite_things.clear(bulk=bulk)
         self.assertQuerysetEqual(
-            FunPerson._base_manager.order_by('first_name').filter(favorite_thing_id=self.b1.pk), [
+            FunPerson._base_manager.order_by("first_name").filter(
+                favorite_thing_id=self.b1.pk
+            ),
+            [
                 "Droopy",
             ],
             lambda c: c.first_name,
@@ -358,42 +433,48 @@ class CustomManagerTests(TestCase):
         self.test_removal_through_default_gfk_related_manager(bulk=False)
 
     def test_removal_through_specified_gfk_related_manager(self, bulk=True):
-        Person.objects.create(first_name="Bugs", last_name="Bunny", fun=True, favorite_thing=self.b1)
-        droopy = Person.objects.create(first_name="Droopy", last_name="Dog", fun=False, favorite_thing=self.b1)
+        Person.objects.create(
+            first_name="Bugs", last_name="Bunny", fun=True, favorite_thing=self.b1
+        )
+        droopy = Person.objects.create(
+            first_name="Droopy", last_name="Dog", fun=False, favorite_thing=self.b1
+        )
 
-        # Check that the fun manager DOESN'T remove boring people.
-        self.b1.favorite_things(manager='fun_people').remove(droopy, bulk=bulk)
+        # The fun manager DOESN'T remove boring people.
+        self.b1.favorite_things(manager="fun_people").remove(droopy, bulk=bulk)
         self.assertQuerysetEqual(
-            self.b1.favorite_things(manager='boring_people').all(), [
+            self.b1.favorite_things(manager="boring_people").all(),
+            [
                 "Droopy",
             ],
             lambda c: c.first_name,
             ordered=False,
         )
 
-        # Check that the boring manager DOES remove boring people.
-        self.b1.favorite_things(manager='boring_people').remove(droopy, bulk=bulk)
+        # The boring manager DOES remove boring people.
+        self.b1.favorite_things(manager="boring_people").remove(droopy, bulk=bulk)
         self.assertQuerysetEqual(
-            self.b1.favorite_things(manager='boring_people').all(), [
-            ],
+            self.b1.favorite_things(manager="boring_people").all(),
+            [],
             lambda c: c.first_name,
             ordered=False,
         )
         droopy.favorite_thing = self.b1
         droopy.save()
 
-        # Check that the fun manager ONLY clears fun people.
-        self.b1.favorite_things(manager='fun_people').clear(bulk=bulk)
+        # The fun manager ONLY clears fun people.
+        self.b1.favorite_things(manager="fun_people").clear(bulk=bulk)
         self.assertQuerysetEqual(
-            self.b1.favorite_things(manager='boring_people').all(), [
+            self.b1.favorite_things(manager="boring_people").all(),
+            [
                 "Droopy",
             ],
             lambda c: c.first_name,
             ordered=False,
         )
         self.assertQuerysetEqual(
-            self.b1.favorite_things(manager='fun_people').all(), [
-            ],
+            self.b1.favorite_things(manager="fun_people").all(),
+            [],
             lambda c: c.first_name,
             ordered=False,
         )
@@ -404,12 +485,15 @@ class CustomManagerTests(TestCase):
     def test_removal_through_default_m2m_related_manager(self):
         bugs = FunPerson.objects.create(first_name="Bugs", last_name="Bunny", fun=True)
         self.b1.fun_authors.add(bugs)
-        droopy = FunPerson.objects.create(first_name="Droopy", last_name="Dog", fun=False)
+        droopy = FunPerson.objects.create(
+            first_name="Droopy", last_name="Dog", fun=False
+        )
         self.b1.fun_authors.add(droopy)
 
         self.b1.fun_authors.remove(droopy)
         self.assertQuerysetEqual(
-            self.b1.fun_authors.through._default_manager.all(), [
+            self.b1.fun_authors.through._default_manager.all(),
+            [
                 "Bugs",
                 "Droopy",
             ],
@@ -419,7 +503,8 @@ class CustomManagerTests(TestCase):
 
         self.b1.fun_authors.remove(bugs)
         self.assertQuerysetEqual(
-            self.b1.fun_authors.through._default_manager.all(), [
+            self.b1.fun_authors.through._default_manager.all(),
+            [
                 "Droopy",
             ],
             lambda c: c.funperson.first_name,
@@ -429,7 +514,8 @@ class CustomManagerTests(TestCase):
 
         self.b1.fun_authors.clear()
         self.assertQuerysetEqual(
-            self.b1.fun_authors.through._default_manager.all(), [
+            self.b1.fun_authors.through._default_manager.all(),
+            [
                 "Droopy",
             ],
             lambda c: c.funperson.first_name,
@@ -442,38 +528,40 @@ class CustomManagerTests(TestCase):
         droopy = Person.objects.create(first_name="Droopy", last_name="Dog", fun=False)
         self.b1.authors.add(droopy)
 
-        # Check that the fun manager DOESN'T remove boring people.
-        self.b1.authors(manager='fun_people').remove(droopy)
+        # The fun manager DOESN'T remove boring people.
+        self.b1.authors(manager="fun_people").remove(droopy)
         self.assertQuerysetEqual(
-            self.b1.authors(manager='boring_people').all(), [
+            self.b1.authors(manager="boring_people").all(),
+            [
                 "Droopy",
             ],
             lambda c: c.first_name,
             ordered=False,
         )
 
-        # Check that the boring manager DOES remove boring people.
-        self.b1.authors(manager='boring_people').remove(droopy)
+        # The boring manager DOES remove boring people.
+        self.b1.authors(manager="boring_people").remove(droopy)
         self.assertQuerysetEqual(
-            self.b1.authors(manager='boring_people').all(), [
-            ],
+            self.b1.authors(manager="boring_people").all(),
+            [],
             lambda c: c.first_name,
             ordered=False,
         )
         self.b1.authors.add(droopy)
 
-        # Check that the fun manager ONLY clears fun people.
-        self.b1.authors(manager='fun_people').clear()
+        # The fun manager ONLY clears fun people.
+        self.b1.authors(manager="fun_people").clear()
         self.assertQuerysetEqual(
-            self.b1.authors(manager='boring_people').all(), [
+            self.b1.authors(manager="boring_people").all(),
+            [
                 "Droopy",
             ],
             lambda c: c.first_name,
             ordered=False,
         )
         self.assertQuerysetEqual(
-            self.b1.authors(manager='fun_people').all(), [
-            ],
+            self.b1.authors(manager="fun_people").all(),
+            [],
             lambda c: c.first_name,
             ordered=False,
         )
@@ -482,7 +570,7 @@ class CustomManagerTests(TestCase):
         mgr = models.Manager()
         as_manager, mgr_path, qs_path, args, kwargs = mgr.deconstruct()
         self.assertFalse(as_manager)
-        self.assertEqual(mgr_path, 'django.db.models.manager.Manager')
+        self.assertEqual(mgr_path, "django.db.models.manager.Manager")
         self.assertEqual(args, ())
         self.assertEqual(kwargs, {})
 
@@ -490,29 +578,47 @@ class CustomManagerTests(TestCase):
         mgr = CustomQuerySet.as_manager()
         as_manager, mgr_path, qs_path, args, kwargs = mgr.deconstruct()
         self.assertTrue(as_manager)
-        self.assertEqual(qs_path, 'custom_managers.models.CustomQuerySet')
+        self.assertEqual(qs_path, "custom_managers.models.CustomQuerySet")
 
     def test_deconstruct_from_queryset(self):
-        mgr = DeconstructibleCustomManager('a', 'b')
+        mgr = DeconstructibleCustomManager("a", "b")
         as_manager, mgr_path, qs_path, args, kwargs = mgr.deconstruct()
         self.assertFalse(as_manager)
-        self.assertEqual(mgr_path, 'custom_managers.models.DeconstructibleCustomManager')
-        self.assertEqual(args, ('a', 'b',))
+        self.assertEqual(
+            mgr_path, "custom_managers.models.DeconstructibleCustomManager"
+        )
+        self.assertEqual(
+            args,
+            (
+                "a",
+                "b",
+            ),
+        )
         self.assertEqual(kwargs, {})
 
-        mgr = DeconstructibleCustomManager('x', 'y', c=3, d=4)
+        mgr = DeconstructibleCustomManager("x", "y", c=3, d=4)
         as_manager, mgr_path, qs_path, args, kwargs = mgr.deconstruct()
         self.assertFalse(as_manager)
-        self.assertEqual(mgr_path, 'custom_managers.models.DeconstructibleCustomManager')
-        self.assertEqual(args, ('x', 'y',))
-        self.assertEqual(kwargs, {'c': 3, 'd': 4})
+        self.assertEqual(
+            mgr_path, "custom_managers.models.DeconstructibleCustomManager"
+        )
+        self.assertEqual(
+            args,
+            (
+                "x",
+                "y",
+            ),
+        )
+        self.assertEqual(kwargs, {"c": 3, "d": 4})
 
     def test_deconstruct_from_queryset_failing(self):
-        mgr = CustomManager('arg')
-        msg = ("Could not find manager BaseCustomManagerFromCustomQuerySet in "
-               "django.db.models.manager.\n"
-               "Please note that you need to inherit from managers you "
-               "dynamically generated with 'from_queryset()'.")
+        mgr = CustomManager("arg")
+        msg = (
+            "Could not find manager BaseCustomManagerFromCustomQuerySet in "
+            "django.db.models.manager.\n"
+            "Please note that you need to inherit from managers you "
+            "dynamically generated with 'from_queryset()'."
+        )
         with self.assertRaisesMessage(ValueError, msg):
             mgr.deconstruct()
 
@@ -521,15 +627,15 @@ class CustomManagerTests(TestCase):
         A custom manager may be defined on an abstract model.
         It will be inherited by the abstract model's children.
         """
-        PersonFromAbstract.abstract_persons.create(objects='Test')
+        PersonFromAbstract.abstract_persons.create(objects="Test")
         self.assertQuerysetEqual(
-            PersonFromAbstract.abstract_persons.all(), ["Test"],
+            PersonFromAbstract.abstract_persons.all(),
+            ["Test"],
             lambda c: c.objects,
         )
 
 
 class TestCars(TestCase):
-
     def test_managers(self):
         # Each model class gets a "_default_manager" attribute, which is a
         # reference to the first manager defined in the class.
@@ -537,25 +643,60 @@ class TestCars(TestCase):
         Car.cars.create(name="Neon", mileage=31, top_speed=100)
 
         self.assertQuerysetEqual(
-            Car._default_manager.order_by("name"), [
+            Car._default_manager.order_by("name"),
+            [
                 "Corvette",
                 "Neon",
             ],
-            lambda c: c.name
+            lambda c: c.name,
         )
         self.assertQuerysetEqual(
-            Car.cars.order_by("name"), [
+            Car.cars.order_by("name"),
+            [
                 "Corvette",
                 "Neon",
             ],
-            lambda c: c.name
+            lambda c: c.name,
         )
         # alternate manager
         self.assertQuerysetEqual(
-            Car.fast_cars.all(), [
+            Car.fast_cars.all(),
+            [
                 "Corvette",
             ],
-            lambda c: c.name
+            lambda c: c.name,
+        )
+        # explicit default manager
+        self.assertQuerysetEqual(
+            FastCarAsDefault.cars.order_by("name"),
+            [
+                "Corvette",
+                "Neon",
+            ],
+            lambda c: c.name,
+        )
+        self.assertQuerysetEqual(
+            FastCarAsDefault._default_manager.all(),
+            [
+                "Corvette",
+            ],
+            lambda c: c.name,
+        )
+        # explicit base manager
+        self.assertQuerysetEqual(
+            FastCarAsBase.cars.order_by("name"),
+            [
+                "Corvette",
+                "Neon",
+            ],
+            lambda c: c.name,
+        )
+        self.assertQuerysetEqual(
+            FastCarAsBase._base_manager.all(),
+            [
+                "Corvette",
+            ],
+            lambda c: c.name,
         )
 
 
@@ -574,13 +715,42 @@ class CustomManagersRegressTestCase(TestCase):
         # there would now be two objects in the database.
         self.assertEqual(RestrictedModel.plain_manager.count(), 1)
 
+    def test_refresh_from_db_when_default_manager_filters(self):
+        """
+        Model.refresh_from_db() works for instances hidden by the default
+        manager.
+        """
+        book = Book._base_manager.create(is_published=False)
+        Book._base_manager.filter(pk=book.pk).update(title="Hi")
+        book.refresh_from_db()
+        self.assertEqual(book.title, "Hi")
+
+    def test_save_clears_annotations_from_base_manager(self):
+        """Model.save() clears annotations from the base manager."""
+        self.assertEqual(Book._meta.base_manager.name, "annotated_objects")
+        book = Book.annotated_objects.create(title="Hunting")
+        Person.objects.create(
+            first_name="Bugs",
+            last_name="Bunny",
+            fun=True,
+            favorite_book=book,
+            favorite_thing_id=1,
+        )
+        book = Book.annotated_objects.first()
+        self.assertEqual(book.favorite_avg, 1)  # Annotation from the manager.
+        book.title = "New Hunting"
+        # save() fails if annotations that involve related fields aren't
+        # cleared before the update query.
+        book.save()
+        self.assertEqual(Book.annotated_objects.first().title, "New Hunting")
+
     def test_delete_related_on_filtered_manager(self):
         """Deleting related objects should also not be distracted by a
         restricted manager on the related object. This is a regression
         test for #2698."""
         related = RelatedModel.objects.create(name="xyzzy")
 
-        for name, public in (('one', True), ('two', False), ('three', False)):
+        for name, public in (("one", True), ("two", False), ("three", False)):
             RestrictedModel.objects.create(name=name, is_public=public, related=related)
 
         obj = RelatedModel.objects.get(name="xyzzy")
