@@ -52,7 +52,7 @@ class QTests(SimpleTestCase):
             q & obj
 
     def test_combine_negated_boolean_expression(self):
-        tagged = Tag.objects.filter(category=OuterRef('pk'))
+        tagged = Tag.objects.filter(category=OuterRef("pk"))
         tests = [
             Q() & ~Exists(tagged),
             Q() | ~Exists(tagged),
@@ -62,82 +62,91 @@ class QTests(SimpleTestCase):
                 self.assertIs(q.negated, True)
 
     def test_deconstruct(self):
-        q = Q(price__gt=F('discounted_price'))
+        q = Q(price__gt=F("discounted_price"))
         path, args, kwargs = q.deconstruct()
-        self.assertEqual(path, 'django.db.models.Q')
-        self.assertEqual(args, (('price__gt', F('discounted_price')),))
+        self.assertEqual(path, "django.db.models.Q")
+        self.assertEqual(args, (("price__gt", F("discounted_price")),))
         self.assertEqual(kwargs, {})
 
     def test_deconstruct_negated(self):
-        q = ~Q(price__gt=F('discounted_price'))
+        q = ~Q(price__gt=F("discounted_price"))
         path, args, kwargs = q.deconstruct()
-        self.assertEqual(args, (('price__gt', F('discounted_price')),))
-        self.assertEqual(kwargs, {'_negated': True})
+        self.assertEqual(args, (("price__gt", F("discounted_price")),))
+        self.assertEqual(kwargs, {"_negated": True})
 
     def test_deconstruct_or(self):
-        q1 = Q(price__gt=F('discounted_price'))
-        q2 = Q(price=F('discounted_price'))
+        q1 = Q(price__gt=F("discounted_price"))
+        q2 = Q(price=F("discounted_price"))
         q = q1 | q2
         path, args, kwargs = q.deconstruct()
-        self.assertEqual(args, (
-            ('price__gt', F('discounted_price')),
-            ('price', F('discounted_price')),
-        ))
-        self.assertEqual(kwargs, {'_connector': 'OR'})
+        self.assertEqual(
+            args,
+            (
+                ("price__gt", F("discounted_price")),
+                ("price", F("discounted_price")),
+            ),
+        )
+        self.assertEqual(kwargs, {"_connector": "OR"})
 
     def test_deconstruct_and(self):
-        q1 = Q(price__gt=F('discounted_price'))
-        q2 = Q(price=F('discounted_price'))
+        q1 = Q(price__gt=F("discounted_price"))
+        q2 = Q(price=F("discounted_price"))
         q = q1 & q2
         path, args, kwargs = q.deconstruct()
-        self.assertEqual(args, (
-            ('price__gt', F('discounted_price')),
-            ('price', F('discounted_price')),
-        ))
+        self.assertEqual(
+            args,
+            (
+                ("price__gt", F("discounted_price")),
+                ("price", F("discounted_price")),
+            ),
+        )
         self.assertEqual(kwargs, {})
 
     def test_deconstruct_multiple_kwargs(self):
-        q = Q(price__gt=F('discounted_price'), price=F('discounted_price'))
+        q = Q(price__gt=F("discounted_price"), price=F("discounted_price"))
         path, args, kwargs = q.deconstruct()
-        self.assertEqual(args, (
-            ('price', F('discounted_price')),
-            ('price__gt', F('discounted_price')),
-        ))
+        self.assertEqual(
+            args,
+            (
+                ("price", F("discounted_price")),
+                ("price__gt", F("discounted_price")),
+            ),
+        )
         self.assertEqual(kwargs, {})
 
     def test_deconstruct_nested(self):
-        q = Q(Q(price__gt=F('discounted_price')))
+        q = Q(Q(price__gt=F("discounted_price")))
         path, args, kwargs = q.deconstruct()
-        self.assertEqual(args, (Q(price__gt=F('discounted_price')),))
+        self.assertEqual(args, (Q(price__gt=F("discounted_price")),))
         self.assertEqual(kwargs, {})
 
     def test_deconstruct_boolean_expression(self):
-        expr = RawSQL('1 = 1', BooleanField())
+        expr = RawSQL("1 = 1", BooleanField())
         q = Q(expr)
         _, args, kwargs = q.deconstruct()
         self.assertEqual(args, (expr,))
         self.assertEqual(kwargs, {})
 
     def test_reconstruct(self):
-        q = Q(price__gt=F('discounted_price'))
+        q = Q(price__gt=F("discounted_price"))
         path, args, kwargs = q.deconstruct()
         self.assertEqual(Q(*args, **kwargs), q)
 
     def test_reconstruct_negated(self):
-        q = ~Q(price__gt=F('discounted_price'))
+        q = ~Q(price__gt=F("discounted_price"))
         path, args, kwargs = q.deconstruct()
         self.assertEqual(Q(*args, **kwargs), q)
 
     def test_reconstruct_or(self):
-        q1 = Q(price__gt=F('discounted_price'))
-        q2 = Q(price=F('discounted_price'))
+        q1 = Q(price__gt=F("discounted_price"))
+        q2 = Q(price=F("discounted_price"))
         q = q1 | q2
         path, args, kwargs = q.deconstruct()
         self.assertEqual(Q(*args, **kwargs), q)
 
     def test_reconstruct_and(self):
-        q1 = Q(price__gt=F('discounted_price'))
-        q2 = Q(price=F('discounted_price'))
+        q1 = Q(price__gt=F("discounted_price"))
+        q2 = Q(price=F("discounted_price"))
         q = q1 & q2
         path, args, kwargs = q.deconstruct()
         self.assertEqual(Q(*args, **kwargs), q)
