@@ -1,3 +1,4 @@
+import pickle
 from datetime import datetime
 from functools import partialmethod
 from io import StringIO
@@ -5,15 +6,26 @@ from unittest import mock, skipIf
 
 from django.core import serializers
 from django.core.serializers import SerializerDoesNotExist
-from django.core.serializers.base import ProgressBar
+from django.core.serializers.base import PickleSerializer, ProgressBar
 from django.db import connection, transaction
 from django.http import HttpResponse
 from django.test import SimpleTestCase, override_settings, skipUnlessDBFeature
 from django.test.utils import Approximate
 
 from .models import (
-    Actor, Article, Author, AuthorProfile, BaseModel, Category, Child,
-    ComplexModel, Movie, Player, ProxyBaseModel, ProxyProxyBaseModel, Score,
+    Actor,
+    Article,
+    Author,
+    AuthorProfile,
+    BaseModel,
+    Category,
+    Child,
+    ComplexModel,
+    Movie,
+    Player,
+    ProxyBaseModel,
+    ProxyProxyBaseModel,
+    Score,
     Team,
 )
 
@@ -33,22 +45,25 @@ class SerializerRegistrationTests(SimpleTestCase):
 
     def test_register(self):
         "Registering a new serializer populates the full registry. Refs #14823"
-        serializers.register_serializer('json3', 'django.core.serializers.json')
+        serializers.register_serializer("json3", "django.core.serializers.json")
 
         public_formats = serializers.get_public_serializer_formats()
-        self.assertIn('json3', public_formats)
-        self.assertIn('json2', public_formats)
-        self.assertIn('xml', public_formats)
+        self.assertIn("json3", public_formats)
+        self.assertIn("json2", public_formats)
+        self.assertIn("xml", public_formats)
 
     def test_unregister(self):
-        "Unregistering a serializer doesn't cause the registry to be repopulated. Refs #14823"
-        serializers.unregister_serializer('xml')
-        serializers.register_serializer('json3', 'django.core.serializers.json')
+        """
+        Unregistering a serializer doesn't cause the registry to be
+        repopulated.
+        """
+        serializers.unregister_serializer("xml")
+        serializers.register_serializer("json3", "django.core.serializers.json")
 
         public_formats = serializers.get_public_serializer_formats()
 
-        self.assertNotIn('xml', public_formats)
-        self.assertIn('json3', public_formats)
+        self.assertNotIn("xml", public_formats)
+        self.assertIn("json3", public_formats)
 
     def test_unregister_unknown_serializer(self):
         with self.assertRaises(SerializerDoesNotExist):
@@ -59,14 +74,14 @@ class SerializerRegistrationTests(SimpleTestCase):
         all_formats = set(serializers.get_serializer_formats())
         public_formats = set(serializers.get_public_serializer_formats())
 
-        self.assertIn('xml', all_formats),
-        self.assertIn('xml', public_formats)
+        self.assertIn("xml", all_formats),
+        self.assertIn("xml", public_formats)
 
-        self.assertIn('json2', all_formats)
-        self.assertIn('json2', public_formats)
+        self.assertIn("json2", all_formats)
+        self.assertIn("json2", public_formats)
 
-        self.assertIn('python', all_formats)
-        self.assertNotIn('python', public_formats)
+        self.assertIn("python", all_formats)
+        self.assertNotIn("python", public_formats)
 
     def test_get_unknown_serializer(self):
         """
@@ -79,9 +94,8 @@ class SerializerRegistrationTests(SimpleTestCase):
             serializers.get_serializer("nonsense")
 
         # SerializerDoesNotExist is instantiated with the nonexistent format
-        with self.assertRaises(SerializerDoesNotExist) as cm:
+        with self.assertRaisesMessage(SerializerDoesNotExist, "nonsense"):
             serializers.get_serializer("nonsense")
-        self.assertEqual(cm.exception.args, ("nonsense",))
 
     def test_get_unknown_deserializer(self):
         with self.assertRaises(SerializerDoesNotExist):
@@ -91,29 +105,30 @@ class SerializerRegistrationTests(SimpleTestCase):
 class SerializersTestBase:
     serializer_name = None  # Set by subclasses to the serialization format name
 
-    def setUp(self):
+    @classmethod
+    def setUpTestData(cls):
         sports = Category.objects.create(name="Sports")
         music = Category.objects.create(name="Music")
         op_ed = Category.objects.create(name="Op-Ed")
 
-        self.joe = Author.objects.create(name="Joe")
-        self.jane = Author.objects.create(name="Jane")
+        cls.joe = Author.objects.create(name="Joe")
+        cls.jane = Author.objects.create(name="Jane")
 
-        self.a1 = Article(
-            author=self.jane,
+        cls.a1 = Article(
+            author=cls.jane,
             headline="Poker has no place on ESPN",
-            pub_date=datetime(2006, 6, 16, 11, 00)
+            pub_date=datetime(2006, 6, 16, 11, 00),
         )
-        self.a1.save()
-        self.a1.categories.set([sports, op_ed])
+        cls.a1.save()
+        cls.a1.categories.set([sports, op_ed])
 
-        self.a2 = Article(
-            author=self.joe,
+        cls.a2 = Article(
+            author=cls.joe,
             headline="Time to reform copyright",
-            pub_date=datetime(2006, 6, 16, 13, 00, 11, 345)
+            pub_date=datetime(2006, 6, 16, 13, 00, 11, 345),
         )
-        self.a2.save()
-        self.a2.categories.set([music, op_ed])
+        cls.a2.save()
+        cls.a2.categories.set([music, op_ed])
 
     def test_serialize(self):
         """Basic serialization works."""
@@ -127,7 +142,7 @@ class SerializersTestBase:
         self.assertEqual(len(models), 2)
 
     def test_serialize_to_stream(self):
-        obj = ComplexModel(field1='first', field2='second', field3='third')
+        obj = ComplexModel(field1="first", field2="second", field3="third")
         obj.save_base(raw=True)
 
         # Serialize the test database to a stream
@@ -144,19 +159,19 @@ class SerializersTestBase:
                 self.assertEqual(string_data, stream.content.decode())
 
     def test_serialize_specific_fields(self):
-        obj = ComplexModel(field1='first', field2='second', field3='third')
+        obj = ComplexModel(field1="first", field2="second", field3="third")
         obj.save_base(raw=True)
 
         # Serialize then deserialize the test database
         serialized_data = serializers.serialize(
-            self.serializer_name, [obj], indent=2, fields=('field1', 'field3')
+            self.serializer_name, [obj], indent=2, fields=("field1", "field3")
         )
         result = next(serializers.deserialize(self.serializer_name, serialized_data))
 
         # The deserialized object contains data in only the serialized fields.
-        self.assertEqual(result.object.field1, 'first')
-        self.assertEqual(result.object.field2, '')
-        self.assertEqual(result.object.field3, 'third')
+        self.assertEqual(result.object.field1, "first")
+        self.assertEqual(result.object.field2, "")
+        self.assertEqual(result.object.field3, "third")
 
     def test_altering_serialized_output(self):
         """
@@ -185,28 +200,34 @@ class SerializersTestBase:
         doesn't appear in the serialized field list - it replaces the pk
         identifier.
         """
-        AuthorProfile.objects.create(author=self.joe, date_of_birth=datetime(1970, 1, 1))
-        serial_str = serializers.serialize(self.serializer_name, AuthorProfile.objects.all())
-        self.assertFalse(self._get_field_values(serial_str, 'author'))
+        AuthorProfile.objects.create(
+            author=self.joe, date_of_birth=datetime(1970, 1, 1)
+        )
+        serial_str = serializers.serialize(
+            self.serializer_name, AuthorProfile.objects.all()
+        )
+        self.assertFalse(self._get_field_values(serial_str, "author"))
 
         for obj in serializers.deserialize(self.serializer_name, serial_str):
             self.assertEqual(obj.object.pk, self.joe.pk)
 
     def test_serialize_field_subset(self):
         """Output can be restricted to a subset of fields"""
-        valid_fields = ('headline', 'pub_date')
+        valid_fields = ("headline", "pub_date")
         invalid_fields = ("author", "categories")
-        serial_str = serializers.serialize(self.serializer_name, Article.objects.all(), fields=valid_fields)
+        serial_str = serializers.serialize(
+            self.serializer_name, Article.objects.all(), fields=valid_fields
+        )
         for field_name in invalid_fields:
             self.assertFalse(self._get_field_values(serial_str, field_name))
 
         for field_name in valid_fields:
             self.assertTrue(self._get_field_values(serial_str, field_name))
 
-    def test_serialize_unicode(self):
+    def test_serialize_unicode_roundtrip(self):
         """Unicode makes the roundtrip intact"""
         actor_name = "Za\u017c\u00f3\u0142\u0107"
-        movie_title = 'G\u0119\u015bl\u0105 ja\u017a\u0144'
+        movie_title = "G\u0119\u015bl\u0105 ja\u017a\u0144"
         ac = Actor(name=actor_name)
         mv = Movie(title=movie_title, actor=ac)
         ac.save()
@@ -220,14 +241,25 @@ class SerializersTestBase:
         mv_obj = obj_list[0].object
         self.assertEqual(mv_obj.title, movie_title)
 
+    def test_unicode_serialization(self):
+        unicode_name = "יוניקוד"
+        data = serializers.serialize(self.serializer_name, [Author(name=unicode_name)])
+        self.assertIn(unicode_name, data)
+        objs = list(serializers.deserialize(self.serializer_name, data))
+        self.assertEqual(objs[0].object.name, unicode_name)
+
     def test_serialize_progressbar(self):
         fake_stdout = StringIO()
         serializers.serialize(
-            self.serializer_name, Article.objects.all(),
-            progress_output=fake_stdout, object_count=Article.objects.count()
+            self.serializer_name,
+            Article.objects.all(),
+            progress_output=fake_stdout,
+            object_count=Article.objects.count(),
         )
         self.assertTrue(
-            fake_stdout.getvalue().endswith('[' + '.' * ProgressBar.progress_width + ']\n')
+            fake_stdout.getvalue().endswith(
+                "[" + "." * ProgressBar.progress_width + "]\n"
+            )
         )
 
     def test_serialize_superfluous_queries(self):
@@ -235,14 +267,27 @@ class SerializersTestBase:
 
         #17602
         """
-        ac = Actor(name='Actor name')
+        ac = Actor(name="Actor name")
         ac.save()
-        mv = Movie(title='Movie title', actor_id=ac.pk)
+        mv = Movie(title="Movie title", actor_id=ac.pk)
         mv.save()
 
         with self.assertNumQueries(0):
             serializers.serialize(self.serializer_name, [mv])
 
+    def test_serialize_prefetch_related_m2m(self):
+        # One query for the Article table and one for each prefetched m2m
+        # field.
+        with self.assertNumQueries(3):
+            serializers.serialize(
+                self.serializer_name,
+                Article.objects.all().prefetch_related("categories", "meta_data"),
+            )
+        # One query for the Article table, and two m2m queries for each
+        # article.
+        with self.assertNumQueries(5):
+            serializers.serialize(self.serializer_name, Article.objects.all())
+
     def test_serialize_with_null_pk(self):
         """
         Serialized data with no primary key results
@@ -253,7 +298,9 @@ class SerializersTestBase:
         pk_value = self._get_pk_values(serial_str)[0]
         self.assertFalse(pk_value)
 
-        cat_obj = list(serializers.deserialize(self.serializer_name, serial_str))[0].object
+        cat_obj = list(serializers.deserialize(self.serializer_name, serial_str))[
+            0
+        ].object
         self.assertIsNone(cat_obj.id)
 
     def test_float_serialization(self):
@@ -265,8 +312,8 @@ class SerializersTestBase:
         self.assertEqual(deserial_objs[0].object.score, Approximate(3.4, places=1))
 
     def test_deferred_field_serialization(self):
-        author = Author.objects.create(name='Victor Hugo')
-        author = Author.objects.defer('name').get(pk=author.pk)
+        author = Author.objects.create(name="Victor Hugo")
+        author = Author.objects.defer("name").get(pk=author.pk)
         serial_str = serializers.serialize(self.serializer_name, [author])
         deserial_objs = list(serializers.deserialize(self.serializer_name, serial_str))
         self.assertIsInstance(deserial_objs[0].object, Author)
@@ -285,7 +332,9 @@ class SerializersTestBase:
         self.assertEqual(team[0], team_str)
 
         deserial_objs = list(serializers.deserialize(self.serializer_name, serial_str))
-        self.assertEqual(deserial_objs[0].object.team.to_string(), player.team.to_string())
+        self.assertEqual(
+            deserial_objs[0].object.team.to_string(), player.team.to_string()
+        )
 
     def test_pre_1000ad_date(self):
         """Year values before 1000AD are properly formatted"""
@@ -294,17 +343,20 @@ class SerializersTestBase:
         a = Article.objects.create(
             author=self.jane,
             headline="Nobody remembers the early years",
-            pub_date=datetime(1, 2, 3, 4, 5, 6))
+            pub_date=datetime(1, 2, 3, 4, 5, 6),
+        )
 
         serial_str = serializers.serialize(self.serializer_name, [a])
         date_values = self._get_field_values(serial_str, "pub_date")
-        self.assertEqual(date_values[0].replace('T', ' '), "0001-02-03 04:05:06")
+        self.assertEqual(date_values[0].replace("T", " "), "0001-02-03 04:05:06")
 
     def test_pkless_serialized_strings(self):
         """
         Serialized strings without PKs can be turned into models
         """
-        deserial_objs = list(serializers.deserialize(self.serializer_name, self.pkless_str))
+        deserial_objs = list(
+            serializers.deserialize(self.serializer_name, self.pkless_str)
+        )
         for obj in deserial_objs:
             self.assertFalse(obj.object.id)
             obj.save()
@@ -313,23 +365,31 @@ class SerializersTestBase:
     def test_deterministic_mapping_ordering(self):
         """Mapping such as fields should be deterministically ordered. (#24558)"""
         output = serializers.serialize(self.serializer_name, [self.a1], indent=2)
-        categories = self.a1.categories.values_list('pk', flat=True)
-        self.assertEqual(output, self.mapping_ordering_str % {
-            'article_pk': self.a1.pk,
-            'author_pk': self.a1.author_id,
-            'first_category_pk': categories[0],
-            'second_category_pk': categories[1],
-        })
+        categories = self.a1.categories.values_list("pk", flat=True)
+        self.assertEqual(
+            output,
+            self.mapping_ordering_str
+            % {
+                "article_pk": self.a1.pk,
+                "author_pk": self.a1.author_id,
+                "first_category_pk": categories[0],
+                "second_category_pk": categories[1],
+            },
+        )
 
     def test_deserialize_force_insert(self):
         """Deserialized content can be saved with force_insert as a parameter."""
         serial_str = serializers.serialize(self.serializer_name, [self.a1])
-        deserial_obj = list(serializers.deserialize(self.serializer_name, serial_str))[0]
-        with mock.patch('django.db.models.Model') as mock_model:
+        deserial_obj = list(serializers.deserialize(self.serializer_name, serial_str))[
+            0
+        ]
+        with mock.patch("django.db.models.Model") as mock_model:
             deserial_obj.save(force_insert=False)
-            mock_model.save_base.assert_called_with(deserial_obj.object, raw=True, using=None, force_insert=False)
+            mock_model.save_base.assert_called_with(
+                deserial_obj.object, raw=True, using=None, force_insert=False
+            )
 
-    @skipUnlessDBFeature('can_defer_constraint_checks')
+    @skipUnlessDBFeature("can_defer_constraint_checks")
     def test_serialize_proxy_model(self):
         BaseModel.objects.create(parent_data=1)
         base_objects = BaseModel.objects.all()
@@ -338,20 +398,19 @@ class SerializersTestBase:
         base_data = serializers.serialize("json", base_objects)
         proxy_data = serializers.serialize("json", proxy_objects)
         proxy_proxy_data = serializers.serialize("json", proxy_proxy_objects)
-        self.assertEqual(base_data, proxy_data.replace('proxy', ''))
-        self.assertEqual(base_data, proxy_proxy_data.replace('proxy', ''))
+        self.assertEqual(base_data, proxy_data.replace("proxy", ""))
+        self.assertEqual(base_data, proxy_proxy_data.replace("proxy", ""))
 
     def test_serialize_inherited_fields(self):
-        child_1 = Child.objects.create(parent_data='a', child_data='b')
-        child_2 = Child.objects.create(parent_data='c', child_data='d')
+        child_1 = Child.objects.create(parent_data="a", child_data="b")
+        child_2 = Child.objects.create(parent_data="c", child_data="d")
         child_1.parent_m2m.add(child_2)
         child_data = serializers.serialize(self.serializer_name, [child_1, child_2])
-        self.assertEqual(self._get_field_values(child_data, 'parent_m2m'), [])
-        self.assertEqual(self._get_field_values(child_data, 'parent_data'), [])
+        self.assertEqual(self._get_field_values(child_data, "parent_m2m"), [])
+        self.assertEqual(self._get_field_values(child_data, "parent_data"), [])
 
 
 class SerializerAPITests(SimpleTestCase):
-
     def test_stream_class(self):
         class File:
             def __init__(self):
@@ -361,7 +420,7 @@ class SerializerAPITests(SimpleTestCase):
                 self.lines.append(line)
 
             def getvalue(self):
-                return ''.join(self.lines)
+                return "".join(self.lines)
 
         class Serializer(serializers.json.Serializer):
             stream_class = File
@@ -370,14 +429,16 @@ class SerializerAPITests(SimpleTestCase):
         data = serializer.serialize([Score(id=1, score=3.4)])
         self.assertIs(serializer.stream_class, File)
         self.assertIsInstance(serializer.stream, File)
-        self.assertEqual(data, '[{"model": "serializers.score", "pk": 1, "fields": {"score": 3.4}}]')
+        self.assertEqual(
+            data, '[{"model": "serializers.score", "pk": 1, "fields": {"score": 3.4}}]'
+        )
 
 
 class SerializersTransactionTestBase:
 
-    available_apps = ['serializers']
+    available_apps = ["serializers"]
 
-    @skipUnlessDBFeature('supports_forward_references')
+    @skipUnlessDBFeature("supports_forward_references")
     def test_forward_refs(self):
         """
         Objects ids can be referenced before they are
@@ -398,16 +459,33 @@ class SerializersTransactionTestBase:
         self.assertEqual(art_obj.author.name, "Agnes")
 
 
+class PickleSerializerTests(SimpleTestCase):
+    def test_serializer_protocol(self):
+        serializer = PickleSerializer(protocol=3)
+        self.assertEqual(serializer.protocol, 3)
+        # If protocol is not provided, it defaults to pickle.HIGHEST_PROTOCOL
+        serializer = PickleSerializer()
+        self.assertEqual(serializer.protocol, pickle.HIGHEST_PROTOCOL)
+
+    def test_serializer_loads_dumps(self):
+        serializer = PickleSerializer()
+        test_data = "test data"
+        dump = serializer.dumps(test_data)
+        self.assertEqual(serializer.loads(dump), test_data)
+
+
 def register_tests(test_class, method_name, test_func, exclude=()):
     """
     Dynamically create serializer tests to ensure that all registered
     serializers are automatically tested.
     """
     for format_ in serializers.get_serializer_formats():
-        if format_ == 'geojson' or format_ in exclude:
+        if format_ == "geojson" or format_ in exclude:
             continue
         decorated_func = skipIf(
             isinstance(serializers.get_serializer(format_), serializers.BadSerializer),
-            'The Python library for the %s serializer is not installed.' % format_,
+            "The Python library for the %s serializer is not installed." % format_,
         )(test_func)
-        setattr(test_class, method_name % format_, partialmethod(decorated_func, format_))
+        setattr(
+            test_class, method_name % format_, partialmethod(decorated_func, format_)
+        )
